# deklare

deklare is a data processing framework designed for data exploration. It allows to create software-defined datasets, which can dynamically load and process data on-demand in a declarative way.

## Quickstart

```
pip install deklare
```

## Development Quickstart
- Clone the repo and open its folder in a terminal
- [Install rye](https://rye.astral.sh/guide/installation/), then
- Install dependencies
```
rye sync --all-features
```